import 'package:flutter/material.dart';
import 'package:nb_utils/nb_utils.dart';

enum WidgetType { DROPDOWN, LIST }

/// Use SELECTED_LANGUAGE_CODE Pref key to get selected language code
class LanguageListWidget extends StatefulWidget {
  static String tag = '/LanguageSelectionWidget';
  final WidgetType widgetType;
  final void Function(LanguageDataModel)? onLanguageChange;
  final ScrollPhysics? scrollPhysics;
  final Widget? trailing;

  LanguageListWidget({
    this.widgetType = WidgetType.LIST,
    this.onLanguageChange,
    this.scrollPhysics,
    this.trailing,
  });

  @override
  LanguageListWidgetState createState() => LanguageListWidgetState();
}

class LanguageListWidgetState extends State<LanguageListWidget> {
  @override
  void initState() {
    super.initState();
    init();
  }

  Future<void> init() async {
    //
  }

  @override
  void setState(fn) {
    if (mounted) super.setState(fn);
  }

  Widget build(BuildContext context) {
    if (widget.widgetType == WidgetType.LIST) {
      return Container(
        child: ListView.builder(
          itemBuilder: (_, index) {
            LanguageDataModel data = localeLanguageList[index];

            return SettingItemWidget(
              title: data.name.validate(),
              subTitle: data.subTitle,
              leading: Image.asset(data.flag.validate(), height: 24),
              trailing: Container(
                child: widget.trailing ??
                    Container(
                      padding: EdgeInsets.all(2),
                      decoration: boxDecorationDefault(shape: BoxShape.circle),
                      child: Icon(Icons.check, size: 15, color: Colors.black),
                    ),
              ).visible(getStringAsync(SELECTED_LANGUAGE_CODE) ==
                  data.languageCode.validate()),
              onTap: () async {
                await setValue(SELECTED_LANGUAGE_CODE, data.languageCode);

                selectedLanguageDataModel = data;

                setState(() {});
                widget.onLanguageChange?.call(data);
              },
            );
          },
          shrinkWrap: true,
          physics: widget.scrollPhysics,
          itemCount: localeLanguageList.length,
        ),
      );
    } else {
      return DropdownButton<LanguageDataModel>(
        value: selectedLanguageDataModel,
        onChanged: (LanguageDataModel? data) async {
          selectedLanguageDataModel = data;

          await setValue(
              SELECTED_LANGUAGE_CODE, data!.fullLanguageCode.validate());

          setState(() {});
          widget.onLanguageChange?.call(data);
        },
        items: localeLanguageList.map((e) {
          return DropdownMenuItem<LanguageDataModel>(
            child: Text(e.name.validate()),
            value: e,
          );
        }).toList(),
      );
    }
  }
}
